@@ -47,6 +47,18 @@ class LinkStatus
 {
 public:
 
+    enum Status {
+        UNDETERMINED,
+        SUCCESSFULL,
+        BROKEN,
+        HTTP_REDIRECTION,
+        HTTP_CLIENT_ERROR,
+        HTTP_SERVER_ERROR,
+        TIMEOUT,
+        NOT_SUPPORTED,
+        MALFORMED
+    };
+    
     LinkStatus();
     LinkStatus(KURL const& absolute_url);
     LinkStatus(Node* node, LinkStatus* parent);
@@ -56,6 +68,7 @@ public:
     
     void reset();
     void setRootUrl(KURL const& url);
+    void setStatus(Status status);
     void setDepth(uint depth);
     void setParent(LinkStatus* parent);
     void setOriginalUrl(QString const& url_original);
@@ -63,7 +76,7 @@ public:
     void setAbsoluteUrl(KURL const& url_absoluto);
     void setDocHtml(QString const& doc_html);
     void setHttpHeader(HttpResponseHeader const& cabecalho_http);
-    void setStatus(QString const& status);
+    void setStatusText(QString const& statusText); // FIXME Legacy. This should be eliminated in favor of LinkStatus::Status
     void setError(QString const& error);
     void setIsRoot(bool flag);
     void setErrorOccurred(bool houve_error);
@@ -89,8 +102,9 @@ public:
     void addReferrer(KURL const& url);
 
     KURL const& rootUrl() const;
+    Status const& status() const;
     uint depth() const;
-    bool local() const; 		// linkstatus.paradigma.co.pt == paradigma.co.pt
+    bool local() const;         // linkstatus.paradigma.co.pt == paradigma.co.pt
     bool isLocalRestrict() const; // linkstatus.paradigma.co.pt != paradigma.co.pt
     LinkStatus const* parent() const;
     QString const& originalUrl() const;
@@ -99,7 +113,7 @@ public:
     QString const& docHtml() const;
     HttpResponseHeader const& httpHeader() const;
     HttpResponseHeader& httpHeader();
-    QString status() const;
+    QString statusText() const; // FIXME Legacy. This should be eliminated in favor of LinkStatus::Status
     QString const& error() const;
     bool isRoot() const;
     bool errorOccurred() const;
@@ -135,6 +149,7 @@ private:
 private:
 
     KURL root_url_; // The URL which made the search start
+    Status status_;
     int depth_;
     int external_domain_depth_; // Para se poder escolher explorar domains diferentes ate n depth
     QString original_url_;
@@ -142,7 +157,7 @@ private:
     KURL absolute_url_;
     QString doc_html_;
     HttpResponseHeader http_header_;
-    QString status_;
+    QString status_text_; // FIXME Legacy. This should be eliminated in favor of LinkStatus::Status
     QString error_;
     bool is_root_;
     bool error_occurred_;
