@@ -125,7 +125,7 @@ QString KommanderWidget::evalAssociatedText() // expands and returns associated
 QString KommanderWidget::evalAssociatedText(const QString& a_text)
 {
   /* New internal parser is used if global flag is set */
-  if ((KommanderWidget::useInternalParser && !a_text.startsWith("#!")) || a_text.startsWith("#!kommander"))  
+  if ((KommanderWidget::useInternalParser && !a_text.startsWith("#!")) || a_text.startsWith("#!kommander"))
   {
     Parser p(internalParserData());
     p.setString(a_text);
@@ -133,7 +133,7 @@ QString KommanderWidget::evalAssociatedText(const QString& a_text)
     if (!p.parse())
     {
       // FIXME add widget's name to KommanderWidget class      
-      printError(i18n("Line %1: error: %2\n").arg(p.errorLine()).arg(p.errorMessage()));
+      printError(i18n("Line %1: %2.\n").arg(p.errorLine()+1).arg(p.errorMessage()));
     }
     return QString::null;
   }
@@ -254,6 +254,11 @@ QString KommanderWidget::DCOPQuery(const QStringList& a_query)
   bool ok = false;
   if (start != -1)
     pTypes = parseBrackets(function, start, ok);
+  else
+  {
+    ok = true;
+    function += "()";
+  }
   if (!ok)
   {
     printError(i18n("Unmatched parenthesis in DCOP call \'%1\'.").arg(a_query[2]));
@@ -279,7 +284,7 @@ QString KommanderWidget::DCOPQuery(const QStringList& a_query)
     else if (argTypes[i] == "double")
       byteDataStream << a_query[i+3].toDouble();
     else if (argTypes[i] == "bool")
-      byteDataStream << (bool)(a_query[i+3] != "false" && a_query[i+3] != "FALSE" && a_query[i+3] != "0");
+      byteDataStream << (bool)(a_query[i+3] != "false" && a_query[i+3] != "false" && a_query[i+3] != "0");
     else if (argTypes[i] == "QStringList")
       if (a_query[i+3].find('\n') != -1)
         byteDataStream << QStringList::split("\n", a_query[i+3], true);
@@ -534,6 +539,12 @@ bool KommanderWidget::isWidget(const QString& a_name) const
   return parseWidget(a_name);  
 }
 
+KommanderWidget* KommanderWidget::widgetByName(const QString& a_name) const
+{
+  return parseWidget(a_name);
+}
+
+
 KommanderWidget* KommanderWidget::parseWidget(const QString& widgetName) const
 {
   if (QString(parentDialog()->name()) == widgetName) 
@@ -648,14 +659,36 @@ void KommanderWidget::setGlobal(const QString& variableName, const QString& valu
   m_globals.insert(variableName, value); 
 }  
 
-QString KommanderWidget::handleDCOP(const int, const QStringList&)
+QString KommanderWidget::handleDCOP(const int function, const QStringList& args)
 {
+  QWidget* current = dynamic_cast<QWidget*>(m_thisObject);
+  if (!current) 
+    return QString::null;
+  switch(function) {
+    case DCOP::setEnabled:
+      current->setEnabled(args[0] != "false" && args[0] != "0");
+      break;
+    case DCOP::setVisible:
+      current->setShown(args[0] != "false" && args[0] != "0");
+      break;
+    case DCOP::type:
+      return current->className();      
+    case DCOP::children:
+    {
+      QStringList matching;
+      QObjectList* widgets = current->queryList("QWidget", 0, false, args.count() == 0 || args[0] != "false");
+      for (QObject* w = widgets->first(); w; w = widgets->next())
+        if (w->name() && (dynamic_cast<KommanderWidget*>(w)))
+            matching.append(w->name());
+      return matching.join("\n");  
+    }  
+  }
   return QString::null;
 }
 
-bool KommanderWidget::isFunctionSupported(int)
+bool KommanderWidget::isFunctionSupported(int f)
 {
-  return true;  
+  return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::children || f == DCOP::type;
 }
 
 bool KommanderWidget::isCommonFunction(int f)
