@@ -137,7 +137,7 @@ xslDbgShellPrintList(xmlShellCtxtPtr ctxt, xmlChar * arg, int dir)
             }
             xmlXPathFreeObject(list);
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg((char*)arg));
+            xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(arg)));
         }
         ctxt->pctxt->node = NULL;
     }
@@ -172,7 +172,7 @@ xslDbgCatToFile(xmlNodePtr node, FILE * file)
         const xmlChar *encoding = doc->encoding;
 
         if (encoding) {
-            xsldbgGenericErrorFunc(i18n("Information: Temporarily setting document's encoding to UTF-8. Previously was %1.\n").arg((char*)encoding));
+            xsldbgGenericErrorFunc(i18n("Information: Temporarily setting document's encoding to UTF-8. Previously was %1.\n").arg(xsldbgText(encoding)));
         }
         doc->encoding = (xmlChar *) "UTF-8";
         xmlDocDump(file, (xmlDocPtr) node);
@@ -226,7 +226,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 	  break;
 	file = fopen(fileName, "w+");
 	if (!file) {
-	   xsldbgGenericErrorFunc(i18n("Error: Unable to save temporary results to %1.\n").arg((char*)fileName));
+	   xsldbgGenericErrorFunc(i18n("Error: Unable to save temporary results to %1.\n").arg(xsldbgText(fileName)));
 	  break;
 	} else {
 	  fprintf(file, "= %s\n", xPath);
@@ -240,7 +240,7 @@ printXPathObject(xmlXPathObjectPtr item, xmlChar* xPath){
 						nodeTab[indx], file);
 	      }
 	    } else {
-	      xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg((char*)xPath));
+	      xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(xPath)));
 	    }
 	    break;
 			     
@@ -380,7 +380,7 @@ xslDbgShellCat(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
         result = printXPathObject(list, arg);
         xmlXPathFreeObject(list);
     } else {
-        xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg((char*)arg));
+        xsldbgGenericErrorFunc(i18n("Error: XPath %1 results in an empty Node Set.\n").arg(xsldbgText(arg)));
     }
     ctxt->pctxt->node = NULL;
     return result;
@@ -415,19 +415,19 @@ xslDbgShellPrintNames(void *payload,
 		     item->nameURI, item->name);
 	}
         if (printVariableValue == 0){
-	    xsldbgGenericErrorFunc(i18n(" Global %1\n").arg((char*)fullQualifiedName));
+	    xsldbgGenericErrorFunc(i18n(" Global %1\n").arg(xsldbgText(fullQualifiedName)));
         }else{
 	      if (item->computed == 1){
 	         xsldbgGenericErrorFunc(i18n(" Global "));
 		 printXPathObject(item->value, fullQualifiedName);
 	      }else if (item->tree){
-	         xsldbgGenericErrorFunc(i18n(" Global = %1\n").arg((char*)fullQualifiedName));
+	         xsldbgGenericErrorFunc(i18n(" Global = %1\n").arg(xsldbgText(fullQualifiedName)));
 		 xslDbgCatToFile(item->tree, stderr);
 	      }else if (item->select){
-	         xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg((char*)fullQualifiedName).arg((char*)item->select));
+	         xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(xsldbgText(item->select)));
 	      }else{
 		/* can't find a value give only a variable name an error message */
-		xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg((char*)fullQualifiedName).arg(i18n("Warning: No value assigned to variable.\n")));
+		xsldbgGenericErrorFunc(i18n(" Global = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(i18n("Warning: No value assigned to variable.\n")));
 	      }
 	    xsltGenericError(xsltGenericErrorContext, "\n\032\032\n");
         }
@@ -550,19 +550,19 @@ xslDbgShellPrintVariable(xsltTransformContextPtr styleCtxt, xmlChar * arg,
 					 item->nameURI, item->name);
 			    }
 			    if (printVariableValue == 0){
-				xsldbgGenericErrorFunc(i18n(" Local %1").arg((char*)fullQualifiedName));
+				xsldbgGenericErrorFunc(i18n(" Local %1").arg(xsldbgText(fullQualifiedName)));
 			    }else{
 			        if (item->computed == 1){
 			           xsldbgGenericErrorFunc(i18n(" Local "));
 			           printXPathObject(item->value, fullQualifiedName);
 			        }else if (item->tree){
-			           xsldbgGenericErrorFunc(i18n(" Local = %1\n").arg((char*)fullQualifiedName));
+			           xsldbgGenericErrorFunc(i18n(" Local = %1\n").arg(xsldbgText(fullQualifiedName)));
 			           xslDbgCatToFile(item->tree, stderr);
 			        }else if (item->select){
-				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg((char*)fullQualifiedName).arg((char*)item->select));
+				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(xsldbgText(item->select)));
 				}else{
 				  /* can't find a value give only a variable name and an error */
-				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg((char*)fullQualifiedName).arg(i18n("Warning: No value assigned to variable.\n")));
+				  xsldbgGenericErrorFunc(i18n(" Local = %1\n%2").arg(xsldbgText(fullQualifiedName)).arg(i18n("Warning: No value assigned to variable.\n")));
 				}
 			    }
 			    xsltGenericError(xsltGenericErrorContext, "\n\032\032\n");
