@@ -192,6 +192,7 @@ bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
 {
   int i = 0;
   bool result;
+  KURL dir3; 
   KURL dir2;
   KURL dir1 = path;
   dir1.setPath("/");
@@ -211,8 +212,9 @@ bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
       dir2 = cdUp(dir2);
     //  debug(d1);
     }
-  //  dir2.setPath(dir2.path(-1));
-    result = KIO::NetAccess::mkdir(dir2, window);
+    dir3 = dir2;
+    dir3.adjustPath(-1); //some servers refuse to create directories ending with a slash
+    result = KIO::NetAccess::mkdir(dir3, window);
     if (dir2.path() == "/" || !result)
       break;
     i++;
