@@ -64,13 +64,13 @@ void QNewToolbarStuff::installResource()
 {
     KURL destURL = KURL::fromPathOrURL(KGlobal::dirs()->saveLocation("data") + resourceDir + "toolbars/" + QFileInfo(m_tarName).fileName());
     bool ok = true;
-    if (QuantaCommon::checkOverwrite(destURL))
+    if (QuantaCommon::checkOverwrite(destURL, parentWidget()))
     {
         if (!QExtFileInfo::copy(KURL::fromPathOrURL(m_tarName), destURL, -1, true, false, parentWidget()))
           ok = false;
         else
         {
-           if (KMessageBox::questionYesNo(parentWidget(), i18n("Do you want to load the newly downloaded toolbar?"), i18n("Load Toolbar")) == KMessageBox::Yes)
+           if (KMessageBox::questionYesNo(parentWidget(), i18n("Do you want to load the newly downloaded toolbar?"), i18n("Load Toolbar"), i18n("Load"), KStdGuiItem::cancel()) == KMessageBox::Yes)
            {
               emit loadToolbarFile(destURL);
            }
@@ -91,13 +91,13 @@ void QNewTemplateStuff::installResource()
 {
     KURL destURL = KURL::fromPathOrURL(KGlobal::dirs()->saveLocation("data") + resourceDir + "templates/" + QFileInfo(m_tarName).fileName());
     bool ok = true;
-    if (QuantaCommon::checkOverwrite(destURL))
+    if (QuantaCommon::checkOverwrite(destURL, parentWidget()))
     {
         if (!QExtFileInfo::copy(KURL::fromPathOrURL(m_tarName), destURL, -1, true, false, parentWidget()))
           ok = false;
         else
         {
-           if (KMessageBox::questionYesNo(parentWidget(), i18n("Do you want to open the newly downloaded template?"), i18n("Open Template")) == KMessageBox::Yes)
+           if (KMessageBox::questionYesNo(parentWidget(), i18n("Do you want to open the newly downloaded template?"), i18n("Open Template"), KStdGuiItem::open(), KStdGuiItem::cancel()) == KMessageBox::Yes)
            {
               emit openFile(destURL);
            }
