@@ -104,7 +104,7 @@ void QPEvents::slotEventHappened(const QString& name, const QString& argument1,
               ev.arguments << i18n("An upload was initiated");
               ev.arguments << url.path();
               handleEvent(ev);
-            } 
+            }
         }
         if (inProject && url2.isValid())
         {
@@ -266,53 +266,52 @@ bool QPEvents::handleEvent(const EventAction& ev)
     }
     if (ev.action == "log")
     {
-       QString logFile = ev.arguments[0];
-       KURL url = KURL::fromPathOrURL(logFile);
-       if (url.isValid() && !url.isLocalFile())
-       {
-          KMessageBox::sorry(0L, i18n("Logging to remote files is not supported."));
+      QString logFile = ev.arguments[0];
+      KURL url = KURL::fromPathOrURL(logFile);
+      if (url.isValid() && !url.isLocalFile())
+      {
+        KMessageBox::sorry(0L, i18n("Logging to remote files is not supported."));
+        return false;
+      }
+      if (!logFile.startsWith("/"))
+      {
+        url = Project::ref()->projectBaseURL();
+        url.addPath(logFile);
+        if (!url.isLocalFile())
+        {
+          KMessageBox::sorry(0L, i18n("Logging to files inside a remote project is not supported."));
           return false;
-       }
-       if (!logFile.startsWith("/"))
-       {
-          url = Project::ref()->projectBaseURL();
-          url.addPath(logFile);
-          if (!url.isLocalFile())
-          {
-            KMessageBox::sorry(0L, i18n("Logging to files inside a remote project is not supported."));
-            return false;
-          }
-          QFile file(url.path());
-          bool result;
-          if (ev.arguments[2] == "create_new")
-            result = file.open(IO_WriteOnly);
-          else
-            result = file.open(IO_WriteOnly | IO_Append);
-          if (result)
-          {
-            QTextStream stream(&file);
-            //Note: the log text should not be translated.
-            QString s = QDateTime::currentDateTime().toString(Qt::ISODate) + ": ";
-            s.append( "Event : " + m_eventName + " : ");
-            s.append( "Action: " + ev.action + " : ");
-            if (ev.arguments[1] == "full")
-            {
-              s.append( "Arguments: ");
-              for (uint i = 1; i < ev.arguments.count(); i++)
-                s.append(ev.arguments[i] + " | ");
-            }
-            s[s.length() - 1] = '\n';
-            stream << s;
-            file.close();
-          }
-          if (!result)
-          {
-            KMessageBox::sorry(0L, i18n("<qt>Logging failed. Check that you have write access to <i>%1</i>.").arg(url.prettyURL(KURL::StripFileProtocol)));
-            return false;
-          }
-       } else
-       {
-       }
+        }
+      }
+      QFile file(url.path());
+      bool result;
+      if (ev.arguments[2] == "create_new")
+        result = file.open(IO_WriteOnly);
+      else
+        result = file.open(IO_WriteOnly | IO_Append);
+      if (result)
+      {
+        QTextStream stream(&file);
+        stream.setEncoding(QTextStream::UnicodeUTF8);
+        //Note: the log text should not be translated.
+        QString s = QDateTime::currentDateTime().toString(Qt::ISODate) + ": ";
+        s.append( "Event : " + m_eventName + " : ");
+        s.append( "Action: " + ev.action + " : ");
+        if (ev.arguments[1] == "full")
+        {
+          s.append( "Arguments: ");
+          for (uint i = 1; i < ev.arguments.count(); i++)
+            s.append(ev.arguments[i] + " | ");
+        }
+        s[s.length() - 1] = '\n';
+        stream << s;
+        file.close();
+      }
+      if (!result)
+      {
+        KMessageBox::sorry(0L, i18n("<qt>Logging failed. Check that you have write access to <i>%1</i>.").arg(url.path()));
+        return false;
+      }
     } else
       KMessageBox::sorry(0L, i18n("<qt>Unsupported internal event action : <b>%1</b>.</qt>").arg(ev.action));
   } else
