@@ -468,9 +468,22 @@ void QuantaCommon::removeCommentsAndQuotes(QString &str, const DTDStruct *dtd)
      s = dtd->commentsStartRx.cap();
      if (s == "\\\"" || s == "\\'")
      {
-       str[pos] = space;
-       str[pos+1] = space;
-       pos += 2;
+        int i = pos;
+        int slahNum = 0;
+        while (i > 0 && str[i] == '\\')
+        {
+          slahNum++;
+          i--;
+        }
+        if (slahNum % 2 == 0)
+        {
+          pos++;
+        } else
+        {
+          str[pos] = space;
+          str[pos+1] = space;
+          pos += 2;
+        }
      } else
      {
        s = dtd->comments[s];
@@ -521,9 +534,22 @@ bool QuantaCommon::insideCommentsOrQuotes(int position, const QString &string, c
      s = dtd->commentsStartRx.cap();
      if (s == "\\\"" || s == "\\'")
      {
-       str[pos] = space;
-       str[pos+1] = space;
-       pos += 2;
+        int i = pos;
+        int slahNum = 0;
+        while (i > 0 && str[i] == '\\')
+        {
+          slahNum++;
+          i--;
+        }
+        if (slahNum % 2 == 0)
+        {
+          pos++;
+        } else
+        {
+          str[pos] = space;
+          str[pos+1] = space;
+          pos += 2;
+        }
      } else
      {
        s = dtd->comments[s];
@@ -687,4 +713,32 @@ bool QuantaCommon::checkOverwrite(const KURL& url, QWidget *window)
   return result;
 }
 
+QStringList QuantaCommon::readPathListEntry(KConfig *config, const QString &pKey)
+{
+  QStringList list = config->readPathListEntry(pKey);
+  QStringList::Iterator end = list.end();
+  for (QStringList::Iterator it = list.begin(); it != end; ++it)
+  {
+    KURL u = KURL::fromPathOrURL(*it);
+    if (u.isValid() && u.isLocalFile())
+    {
+      u.setPath(QExtFileInfo::canonicalPath(u.path()));
+      *it = u.url();
+    }
+  }
+  return list;
+}
+
+QString QuantaCommon::readPathEntry(KConfig *config, const QString &pKey)
+{
+  QString path = config->readPathEntry(pKey);
+  KURL u = KURL::fromPathOrURL(path);
+  if (u.isValid() && u.isLocalFile())
+  {
+    u.setPath(QExtFileInfo::canonicalPath(u.path()));
+    path = u.url();
+  }
+  return path;
+}
+
 
